REST API Documentation
============================

This page documents the current views implementing the REST endpoints of the equinox server. The overall structure is as follows:

* api_root (overall API root)
* data_api_root (data API root)
    * DATA_MODEL_api collections of DATA_MODEL
    * DATA_MODEL_detail instances of DATA_MODEL

.. TODO:: Some models only implement collective (list) views, detailed views to be implemented in due course


.. automodule:: equinox.views
   :members:
   :undoc-members:
   :noindex:

